@@ -6,13 +6,14 @@ from typing import cast, get_args, Literal, Optional, overload, TYPE_CHECKING, T
 
 from lxml import html
 
+from compass.core import errors
 from compass.core.interface_base import InterfaceBase
 from compass.core.logger import logger
 from compass.core.schemas import member as schema
 from compass.core.settings import Settings
-from compass.core.utility import maybe_int
-from compass.core.utility import parse
-from compass.core.utility import validation_errors_logging
+from compass.core.util.context_managers import validation_errors_logging
+from compass.core.util.type_coercion import maybe_int
+from compass.core.util.type_coercion import parse
 
 if TYPE_CHECKING:
     from collections.abc import Iterable
@@ -159,7 +160,7 @@ class PeopleScraper(InterfaceBase):
             url += f"&Page={tab_upper}&TAB"
             response = self.s.get(url)
         else:
-            raise ValueError(f"Specified member profile tab {profile_tab} is invalid. Allowed values are {tabs}")
+            raise errors.CompassError(f"Specified member profile tab {profile_tab} is invalid. Allowed values are {tabs}")
 
         return response.content
 
@@ -209,7 +210,7 @@ class PeopleScraper(InterfaceBase):
         tree = html.fromstring(response)
 
         if tree.forms[0].action == "./ScoutsPortal.aspx?Invalid=AccessCN":
-            raise PermissionError(f"You do not have permission to the details of {membership_number}")
+            raise errors.CompassPermissionError(f"You do not have permission to the details of {membership_number}")
 
         details: dict[str, Union[None, int, str, datetime.date, _AddressData, dict[str, str]]] = dict()
 
@@ -323,15 +324,15 @@ class PeopleScraper(InterfaceBase):
         tree = html.fromstring(response)
 
         if tree.forms[0].action == "./ScoutsPortal.aspx?Invalid=AccessCN":
-            raise PermissionError(f"You do not have permission to the details of {membership_number}")
+            raise errors.CompassPermissionError(f"You do not have permission to the details of {membership_number}")
 
         if statuses is None:
             statuses = STATUSES
 
+        primary_role = None
         roles_dates = []
         roles_data = {}
-        rows = tree.xpath("//tbody/tr")
-        for row in rows:
+        for row in tree.xpath("//tbody/tr"):
             # Get children (cells in row)
             cells = list(row)  # filter out empty elements
 
@@ -341,12 +342,13 @@ class PeopleScraper(InterfaceBase):
             if any(el.tag == "input" for el in cells[0]) or cells[0].getchildren() == []:
                 cells.pop(0)
 
+            role_title, primary_role = _extract_primary_role(cells[0].text_content().strip(), primary_role)
             role_status, review_date = _extract_review_date(cells[5].text_content().strip())
 
             role_details = schema.MemberRoleCore(
                 role_number=int(row.get("data-pk")),
                 membership_number=membership_number,
-                role_title=cells[0].text_content().strip(),
+                role_title=role_title,
                 role_class=cells[1].text_content().strip(),
                 # role_type only visible if access to System Admin tab
                 role_type=cells[0][0].get("title", None),
@@ -359,6 +361,9 @@ class PeopleScraper(InterfaceBase):
                 review_date=review_date,
                 can_view_details=any("VIEWROLE" in el.get("class") for el in cells[6]),
             )
+            # Save role number if role is primary
+            if primary_role is True:
+                primary_role = role_details.role_number
             # Remove OHs etc from list
             if "helper" in role_details.role_class.lower() or {role_details.role_title.lower()} <= NON_VOLUNTEER_TITLES:
                 if keep_non_volunteer_roles is False:
@@ -376,7 +381,11 @@ class PeopleScraper(InterfaceBase):
 
         with validation_errors_logging(membership_number):
             # Calculate days of membership (inclusive), normalise to years.
-            return schema.MemberRolesCollection(roles=roles_data, membership_duration=_membership_duration(roles_dates))
+            return schema.MemberRolesCollection(
+                roles=roles_data,
+                membership_duration=_membership_duration(roles_dates),
+                primary_role=primary_role,
+            )
 
     def get_permits_tab(self, membership_number: int) -> list[schema.MemberPermit]:
         """Returns data from Permits tab for a given member.
@@ -536,7 +545,7 @@ class PeopleScraper(InterfaceBase):
         tree = html.fromstring(response)
 
         if tree.forms[0].action == "./ScoutsPortal.aspx?Invalid=AccessCN":
-            raise PermissionError(f"You do not have permission to the details of {membership_number}")
+            raise errors.CompassPermissionError(f"You do not have permission to the details of {membership_number}")
 
         awards = []
         rows = tree.xpath("//table[@class='msAward']/tr")
@@ -586,7 +595,7 @@ class PeopleScraper(InterfaceBase):
         tree = html.fromstring(response)
 
         if tree.forms[0].action == "./ScoutsPortal.aspx?Invalid=AccessCN":
-            raise PermissionError(f"You do not have permission to the details of {membership_number}")
+            raise errors.CompassPermissionError(f"You do not have permission to the details of {membership_number}")
 
         disclosures = []
         rows = tree.xpath("//tbody/tr")
@@ -668,7 +677,7 @@ class PeopleScraper(InterfaceBase):
         fields: html.FieldsDict = form.fields
 
         if form.action == "./ScoutsPortal.aspx?Invalid=Access":
-            raise PermissionError(f"You do not have permission to the details of role {role_number}")
+            raise errors.CompassPermissionError(f"You do not have permission to the details of role {role_number}")
 
         line_manager_number, line_manager_name = _extract_line_manager(inputs["ctl00$workarea$cbo_p2_linemaneger"])
         ce_check = fields.get("ctl00$workarea$txt_p2_cecheck")  # CE (Confidential Enquiry) Check
@@ -742,6 +751,15 @@ def _process_address(address: str) -> _AddressData:
     return dict(unparsed_address=None, country=None, postcode=None, county=None, town=None, street=None)
 
 
+def _extract_primary_role(role_title: str, primary_role: Union[int, None]) -> tuple[str, Union[int, Literal[True], None]]:
+    if primary_role is not None:
+        return role_title, primary_role
+    if role_title.endswith(" [Primary]"):
+        role_title = role_title.removesuffix(" [Primary]")
+        return role_title, True
+    return role_title, primary_role
+
+
 def _extract_review_date(review_status: str) -> tuple[schema.TYPES_ROLE_STATUS, Optional[datetime.date]]:
     if review_status.startswith("Full Review Due ") or review_status.startswith("Full Ending "):
         role_status: schema.TYPES_ROLE_STATUS = "Full"
@@ -947,8 +965,7 @@ def _extract_disclosure_date(disclosure_status: str) -> tuple[Optional[str], Opt
 def _process_hierarchy(inputs: html.InputGetter) -> Iterator[tuple[str, str]]:
     """Get all levels of the org hierarchy and select those that will have information."""
     # Get all inputs with location data
-    # TODO is sorted() needed?
-    for input_name, input_el in sorted(dict(inputs).items()):
+    for input_name, input_el in dict(inputs).items():
         if "ctl00$workarea$cbo_p1_location" not in input_name:
             continue
         level_name = input_el.get("title")
