@@ -284,7 +284,7 @@ class MemberDetails(MemberBase):
             n = phonenumbers.parse(v, "GB")
         except phonenumbers.NumberParseException as err:
             membership_number = values["membership_number"]
-            raise ValueError(f"Member No {membership_number}: phone number {v} is not valid!") from err
+            raise ValueError(f"Member No {membership_number}: phone number {v} is not valid!") from err  # must be a ValueError
 
         if not phonenumbers.is_valid_number(n):
             membership_number = values["membership_number"]
@@ -315,6 +315,7 @@ class MemberRoleCore(MemberBase, MemberRoleBase):
 class MemberRolesCollection(pydantic.BaseModel):
     roles: dict[int, MemberRoleCore]
     membership_duration: float  # Membership duration in qualifying roles, in years
+    primary_role: Union[int, None]  # Primary role number. None if no primary role found
 
 
 # Roles Tab (Role Detail Popup - Main)
